@@ -4,12 +4,7 @@ from jovian.utils.error import ApiError
 from jovian.utils.logger import log
 from jovian.utils.misc import timestamp_ms
 from jovian.utils.request import get, post, pretty
-from jovian.utils.misc import urljoin
-
-
-def _u(path):
-    """Make a URL from the path"""
-    return urljoin(read_api_url(), path)
+from jovian.utils.shared import _u, _v
 
 
 def _h():
@@ -21,13 +16,6 @@ def _h():
             "x-jovian-org": read_org_id()}
 
 
-def _v(version):
-    """Create version query parameter string"""
-    if version is not None:
-        return "?gist_version=" + str(version)
-    return ""
-
-
 def get_current_user():
     res = get(url=_u('/user/profile'), headers=_h())
     if res.status_code == 200:
@@ -58,7 +46,7 @@ def get_gist_access(slug):
     if res.status_code == 200:
         return res.json()['data']
     raise Exception('Failed to retrieve access permission for notebook "' +
-                    slug + '" (retry with create_new=True to create a new notebook): ' + pretty(res))
+                    slug + '" (retry with new_project=True to create a new notebook): ' + pretty(res))
 
 
 def create_gist_simple(filename=None, gist_slug=None, privacy='auto', title=None, version_title=None):
@@ -120,7 +108,7 @@ def post_block(data, data_type, version=None):
     """Upload metrics, hyperparameters and other information to server"""
     blocks = [{"localTimestamp": timestamp_ms(),
                "data": data,
-               'recordType': data_type}]
+               "recordType": data_type}]
     return post_blocks(blocks, version)
 
 
