@@ -1,10 +1,12 @@
 import os
 import click
+import json
 from requests import get
 
 from jovian._version import __version__
 from jovian.utils.constants import ISSUES_MSG
 
+from jovian.utils.api import get_api_key
 from jovian.utils.credentials import get_guest_key, read_api_key_opt, read_api_url, read_org_id
 from jovian.utils.logger import log
 from jovian.utils.rcfile import get_rcdata, rcfile_exists, set_notebook_slug
@@ -39,7 +41,12 @@ def get_gist(slug, version, fresh):
     res = get(url, headers=_h(fresh))
     if res.status_code == 200:
         return res.json()['data']
-    raise Exception('Failed to retrieve Gist: ' + pretty(res))
+    elif res.status_code == 401:
+        log('This notebook does not exist or is private. Please provide the API key')
+        get_api_key()
+        return get_gist(slug, version, fresh)
+    else:
+        log('Failed to retrieve notebook: ' + pretty(res), error=True)
 
 
 def post_clone_msg(title):
@@ -72,6 +79,9 @@ def clone(slug, version=None, fresh=True, include_outputs=True, overwrite=False)
     ver_str = '(version ' + str(version) + ')' if version else ''
     log('Fetching ' + slug + " " + ver_str + "..")
     gist = get_gist(slug, version, fresh)
+    if not gist:
+        return 
+   
     title = gist['title']
 
     # If fresh clone, create directory
@@ -95,8 +105,12 @@ def clone(slug, version=None, fresh=True, include_outputs=True, overwrite=False)
     log('Downloading files..')
     for f in gist['files']:
         if not f['artifact'] or include_outputs:
+            if f['filename'].endswith('.ipynb'):
+                content = _sanitize_notebook(get(f['rawUrl']).content)
+            else:
+                content = get(f['rawUrl']).content
             with open(f['filename'], 'wb') as fp:
-                fp.write(get(f['rawUrl']).content)
+                fp.write(content)
 
         # Create .jovianrc for a fresh clone
         if fresh and f['filename'].endswith('.ipynb'):
@@ -130,3 +144,11 @@ def pull(slug=None, version=None):
     for fname in nbs:
         # Get the latest files for each notebook
         clone(nbs[fname]['slug'], version, fresh=False)
+
+
+def _sanitize_notebook(content):
+    # Delete  kernalspec entry
+    nb_content = json.loads(content.decode("utf-8"))
+    if nb_content.get('metadata', {}).get('kernelspec'):
+        del nb_content['metadata']['kernelspec']
+    return bytes(json.dumps(nb_content), 'utf-8')
